@@ -3,12 +3,8 @@
 This module defines the "ns" enum for natsort is used to determine
 what algorithm natsort uses.
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 import collections
-import warnings
-
-# NOTE: OrderedDict is not used below for compatibility with Python 2.6.
 
 # The below are the base ns options. The values will be stored as powers
 # of two so bitmasks can be used to extract the user's requested options.
@@ -58,26 +54,25 @@ enum_aliases = [
 ]
 
 # Construct the list of bitwise distinct enums with their fields.
-enum_fields = [(name, 1 << i) for i, name in enumerate(enum_options)]
-enum_fields.extend((name, 0) for name in enum_do_nothing)
+enum_fields = collections.OrderedDict(
+    (name, 1 << i) for i, name in enumerate(enum_options)
+)
+enum_fields.update((name, 0) for name in enum_do_nothing)
 
 for name, combo in enum_combos:
-    current_mapping = dict(enum_fields)
-    combined_value = current_mapping[combo[0]]
+    combined_value = enum_fields[combo[0]]
     for combo_name in combo[1:]:
-        combined_value |= current_mapping[combo_name]
-    enum_fields.append((name, combined_value))
+        combined_value |= enum_fields[combo_name]
+    enum_fields[name] = combined_value
 
-current_mapping = dict(enum_fields)
-enum_fields.extend((alias, current_mapping[name]) for alias, name in enum_aliases)
-
-# Finally, extract out the enum field names and their values.
-enum_field_names, enum_field_values = zip(*enum_fields)
+enum_fields.update(
+    (alias, enum_fields[name]) for alias, name in enum_aliases
+)
 
 
 # Subclass the namedtuple to improve the docstring.
 # noinspection PyUnresolvedReferences
-class _NSEnum(collections.namedtuple("_NSEnum", enum_field_names)):
+class _NSEnum(collections.namedtuple("_NSEnum", enum_fields.keys())):
     """
     Enum to control the `natsort` algorithm.
 
@@ -178,16 +173,6 @@ class _NSEnum(collections.namedtuple("_NSEnum", enum_field_names)):
         If an NaN shows up in the input, this instructs `natsort` to
         treat these as +Infinity and place them after all the other numbers.
         By default, an NaN be treated as -Infinity and be placed first.
-    TYPESAFE, T
-        Deprecated as of `natsort` version 5.0.0; this option is now
-        a no-op because it is always true. It will be removed in `natsort`
-        version 6.0.0.
-    VERSION, V
-        Deprecated as of `natsort` version 5.0.0; this option is now
-        a no-op because it is the default. It will be removed in `natsort`
-        version 6.0.0.
-    DIGIT, D
-        Same as `VERSION` above. It will be removed in `natsort` version 6.0.0.
 
     Notes
     -----
@@ -202,43 +187,10 @@ class _NSEnum(collections.namedtuple("_NSEnum", enum_field_names)):
 
     """
 
-    _msg = "ns.{0} is deprecated and will be removed in natsort 6.0.0, "
-    _msg += "this option does nothing so please simply remove its use."
-
-    @property
-    def V(self):  # noqa: N802
-        warnings.warn(self._msg.format("V"), DeprecationWarning, stacklevel=2)
-        return 0
-
-    @property
-    def VERSION(self):  # noqa: N802
-        warnings.warn(self._msg.format("VERSION"), DeprecationWarning, stacklevel=2)
-        return 0
-
-    @property
-    def T(self):  # noqa: N802
-        warnings.warn(self._msg.format("T"), DeprecationWarning, stacklevel=2)
-        return 0
-
-    @property
-    def TYPESAFE(self):  # noqa: N802
-        warnings.warn(self._msg.format("TYPESAFE"), DeprecationWarning, stacklevel=2)
-        return 0
-
-    @property
-    def D(self):  # noqa: N802
-        warnings.warn(self._msg.format("D"), DeprecationWarning, stacklevel=2)
-        return 0
-
-    @property
-    def DIGIT(self):  # noqa: N802
-        warnings.warn(self._msg.format("DIGIT"), DeprecationWarning, stacklevel=2)
-        return 0
-
 
 # Here is where the instance of the ns enum that will be exported is created.
 # It is a poor-man's singleton.
-ns = _NSEnum(*enum_field_values)
+ns = _NSEnum(*enum_fields.values())
 
 # The below is private for internal use only.
-ns_DUMB = 1 << 31
+NS_DUMB = 1 << 31
